@@ -1,28 +1,31 @@
 #ifndef PZK_DISPATCHER_H_
 #define PZK_DISPATCHER_H_
-#include "pzk_dequeue.h"
+#include "pzk_channel.h"
 #include <zookeeper/zookeeper.h>
 
 struct pzk_dispatcher {
-    pzk_dequeue_t* channel;
+    pzk_channel_t* channel;
     void (*notify) (struct pzk_dispatcher*);
 };
 typedef struct pzk_dispatcher pzk_dispatcher_t;
 
+typedef void (*pzk_dispatcher_notify_fn) (struct pzk_dispatcher*);
+
 typedef struct {
     pzk_dispatcher_t* dispatcher;
     void*             event_ctx;
 } pzk_watcher_t;
 
-typedef struct {
+typedef struct pzk_event {
     int   type;
     int   state;
     char* path;
     void* arg;
+
+    void (*destroy) (struct pzk_event*);
 } pzk_event_t;
 
-
-void pzk_dispatcher_cb(
+void pzk_watcher_cb(
     zhandle_t*  zh,
     int         type,
     int         state,
@@ -30,9 +33,13 @@ void pzk_dispatcher_cb(
     void*       watcherCtx
 );
 
-void pzk_dispatcher_auth_cb(int ret, const void* data);
+void pzk_auth_cb(int ret, const void* data);
 
-pzk_event_t* new_pzk_event(int type, int state, const char* path, void* arg);
-void destroy_pzk_event(pzk_event_t*);
+pzk_event_t* new_pzk_event(
+    int         type,
+    int         state,
+    const char* path,
+    void*       arg
+);
 
 #endif // ifndef PZK_DISPATCHER_H_
